@@ -6,20 +6,22 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..8\n"; }
+BEGIN { $| = 1; print "1..11\n"; }
 END {print "not ok 1\n" unless $loaded;}
-use Data::Password qw(IsBadPassword);
+use Data::Password qw(IsBadPassword $MAXLEN);
 $loaded = 1;
 print "ok 1\n";
 
 my %tests = qw(BlaBla 1 blabla 0 cleaner 0 qwerty 0 
-	aB1234 0 xxxZZZ 1 xxxxZZ 0 Abramson 0);
+	aB1234 0 xxxZZZ 1 xxxxZZ 0 
+	Abramson 0 MAxLEN1288457 0 MAXlen12r45f7 1);
 
 my $test = 1;
 
 while (my ($pass, $good) = each %tests) {
 	$test++;
 	print "$pass: ";
+        $MAXLEN = $pass eq 'MAXlen12r45f7' ? 0 : 8;	
 	my $reason = IsBadPassword($pass);
 	print $reason || "good";
 	print ".\n";
